@@ -13,11 +13,7 @@
 #include <QQuickWindow>
 #include <QUrl>
 #include <QtQml>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QtWebEngine>
-#else
 #include <QtWebEngineQuick>
-#endif
 
 #include <KDBusService>
 #include <KLocalizedContext>
@@ -57,7 +53,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
     // Setup QtWebEngine
@@ -70,11 +65,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         chromiumFlags.append(QStringLiteral(" --blink-settings=forceDarkModeEnabled=true"));
     }
     qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromiumFlags.toUtf8());
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QtWebEngine::initialize();
-#else
+
     QtWebEngineQuick::initialize();
-#endif
 
     QApplication app(argc, argv);
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
@@ -84,10 +76,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QGuiApplication::setDesktopFileName(QStringLiteral("org.kde.angelfish"));
     KLocalizedString::setApplicationDomain("angelfish");
 
-#if QT_VERSION <= QT_VERSION_CHECK(5, 14, 0)
-    QtWebEngine::initialize();
-#endif
-
     // Command line parser
     QCommandLineParser parser;
     parser.addPositionalArgument(QStringLiteral("url"), i18n("URL to open"), QStringLiteral("[url]"));
@@ -175,7 +163,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return BrowserManager::instance();
     });
 
-    Q_INIT_RESOURCE(resources);
+    Q_INIT_RESOURCE(resources_angelfish_generated);
 
     QObject::connect(QApplication::instance(), &QCoreApplication::aboutToQuit, QApplication::instance(), [] {
         AngelfishSettings::self()->save();
